@@ -4,6 +4,7 @@ require('/docker/whp/web/configs/config.php');
 require('/docker/whp/web/libs/network.php');
 require('/docker/whp/web/libs/security_manager.php');
 require('/docker/whp/web/libs/permission_checker.php');
+require('/docker/whp/web/libs/delegated_user_manager.php');
 
 // Function to check if current request is to an API endpoint
 function is_api_endpoint() {
@@ -114,11 +115,14 @@ if ($blocked_info) {
 if ( isset($_POST["user"]) && isset($_POST["password"]) ) {
     $results = $SecMan->pam_login($_POST["user"], $_POST["password"]);
     if ( $results == TRUE ) {
-        // Successful login - regenerate session ID to prevent session fixation
+        // Successful PAM login - regenerate session ID to prevent session fixation
         session_regenerate_id(true);
         
         define('AUTH_USER',$_POST["user"]);
         define('HOME_DIR', $SecMan->get_home_dir($_POST["user"]));
+        $_SESSION['user'] = $_POST["user"];
+        $_SESSION['user_type'] = 'system';
+        
         $user_ip = $NetInfo->get_client_ip();
         $nonce = $SecMan->create_nonce($_POST['user'], $user_ip,NONCE_SALT);
         $_SESSION['nonce'] = $nonce;
@@ -136,15 +140,56 @@ if ( isset($_POST["user"]) && isset($_POST["password"]) ) {
         header('Location: /index.php');
         exit();
     } else {
-        // Failed login
+        // PAM login failed, try delegated user authentication
+        $delegatedUserManager = new DelegatedUserManager();
         $user_ip = $NetInfo->get_client_ip();
         $user_agent = isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '';
-        $SecManager->record_failed_login($user_ip, $_POST["user"], $user_agent);
         
-        // Set error message and redirect back to login
-        $_SESSION['login_error'] = 'Invalid username or password.';
-        header('Location: /login.php');
-        exit();
+        $delegated_result = $delegatedUserManager->authenticateDelegatedUser(
+            $_POST["user"], 
+            $_POST["password"], 
+            $user_ip, 
+            $user_agent
+        );
+        
+        if ($delegated_result['success']) {
+            // Successful delegated user login
+            session_regenerate_id(true);
+            
+            // For delegated users, AUTH_USER should be the parent user for resource access
+            // but we track the actual delegated user separately
+            define('AUTH_USER', $delegated_result['user']['parent_username']);
+            $_SESSION['user'] = $delegated_result['user']['parent_username'];
+            $_SESSION['user_type'] = 'delegated';
+            $_SESSION['delegated_user'] = $delegated_result['user']['username'];
+            $_SESSION['parent_user'] = $delegated_result['user']['parent_username'];
+            $_SESSION['delegated_session_id'] = $delegated_result['session_id'];
+            $_SESSION['delegated_user_id'] = $delegated_result['user']['id'];
+            
+            // For delegated users, set HOME_DIR to parent's home
+            define('HOME_DIR', $SecMan->get_home_dir($delegated_result['user']['parent_username']));
+            
+            // Create a nonce for session management (using parent username for consistency)
+            $nonce = $SecMan->create_nonce($delegated_result['user']['parent_username'], $user_ip, NONCE_SALT);
+            $_SESSION['nonce'] = $nonce;
+            
+            // Generate CSRF token for this session
+            if (empty($_SESSION['csrf_token'])) {
+                $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
+            }
+            
+            // Redirect to index page
+            header('Location: /index.php');
+            exit();
+        } else {
+            // Both PAM and delegated login failed
+            $SecManager->record_failed_login($user_ip, $_POST["user"], $user_agent);
+            
+            // Set error message and redirect back to login
+            $_SESSION['login_error'] = 'Invalid username or password.';
+            header('Location: /login.php');
+            exit();
+        }
     }
 }elseif ( isset($_SESSION['nonce'])) {
     //Test login details before getting Nonce configured
@@ -164,8 +209,44 @@ if ( isset($_POST["user"]) && isset($_POST["password"]) ) {
             header('Location: ' . $redirect_address );
         }
     }elseif (is_array($nonce_check) ) {
-        define('AUTH_USER',$nonce_check['user']);
-        define('HOME_DIR',$SecMan->get_home_dir($nonce_check['user']));
+        // Check if this is a delegated user session
+        if (isset($_SESSION['user_type']) && $_SESSION['user_type'] === 'delegated') {
+            // Validate delegated user session
+            if (isset($_SESSION['delegated_session_id'])) {
+                $delegatedUserManager = new DelegatedUserManager();
+                $delegated_user = $delegatedUserManager->getUserBySession($_SESSION['delegated_session_id']);
+                
+                if ($delegated_user) {
+                    // For delegated users, AUTH_USER should be the parent user for resource access
+                    define('AUTH_USER', $delegated_user['parent_username']);
+                    $_SESSION['user'] = $delegated_user['parent_username'];
+                    $_SESSION['delegated_user'] = $delegated_user['username'];
+                    $_SESSION['parent_user'] = $delegated_user['parent_username'];
+                    $_SESSION['delegated_user_id'] = $delegated_user['id'];
+                    define('HOME_DIR', $SecMan->get_home_dir($delegated_user['parent_username']));
+                } else {
+                    // Delegated session expired or invalid, redirect to login
+                    unset($_SESSION['nonce']);
+                    unset($_SESSION['user_type']);
+                    unset($_SESSION['delegated_session_id']);
+                    header('Location: /login.php');
+                    exit();
+                }
+            } else {
+                // No delegated session ID, redirect to login
+                unset($_SESSION['nonce']);
+                unset($_SESSION['user_type']);
+                header('Location: /login.php');
+                exit();
+            }
+        } else {
+            // Regular system user
+            define('AUTH_USER',$nonce_check['user']);
+            define('HOME_DIR',$SecMan->get_home_dir($nonce_check['user']));
+            $_SESSION['user'] = $nonce_check['user'];
+            $_SESSION['user_type'] = 'system';
+        }
+        
         $user_ip = $NetInfo->get_client_ip();
         $nonce = $SecMan->create_nonce($nonce_check['user'], $user_ip,NONCE_SALT);
         $_SESSION['nonce'] = $nonce;
