@@ -171,6 +171,11 @@ if (!array_key_exists($page, $allowed_pages)) {
                     <a href="index.php?page=user-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'user-management' ? 'active' : ''; ?>">
                         <i class="fa fa-users me-3"></i>User Management
                     </a>
+                    <?php endif; ?>
+                    <a href="index.php?page=delegated-users" class="list-group-item list-group-item-action py-3 <?php echo $page === 'delegated-users' ? 'active' : ''; ?>">
+                        <i class="fa fa-user-plus me-3"></i>Delegated Users
+                    </a>
+                    <?php if (defined('AUTH_USER') && AUTH_USER === 'root'): ?>
                     <a href="index.php?page=security-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'security-management' ? 'active' : ''; ?>">
                         <i class="fa fa-shield me-3"></i>Security Management
                     </a>
