@@ -7,23 +7,26 @@
 
 class DelegatedUserManager {
     
-    private $db;
+    private $mysql_mgmt;
     private $permissions_db;
     
     public function __construct() {
-        // Initialize database connections
-        require_once('/docker/whp/web/configs/config.php');
-        $this->db = new PDO("mysql:host=$db_host;dbname=$db_name;charset=utf8mb4", $db_user, $db_pass, [
-            PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
-            PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
-            PDO::ATTR_EMULATE_PREPARES => false
-        ]);
+        // Initialize MySQL management library for database access
+        require_once('/docker/whp/web/libs/mysqlmgmt.php');
+        $this->mysql_mgmt = new mysqlmgmt();
         
         // Initialize permissions database for logging
         $this->permissions_db = new SQLite3('/docker/whp/sql/permissions.db');
         $this->permissions_db->busyTimeout(6000);
     }
     
+    /**
+     * Get MySQL database connection
+     */
+    private function getConnection() {
+        return $this->mysql_mgmt->getMySQLConnection();
+    }
+    
     /**
      * Create a new delegated user
      */
@@ -52,8 +55,14 @@ class DelegatedUserManager {
                 'threads' => 3
             ]);
             
+            // Get database connection
+            $db = $this->getConnection();
+            if (!$db) {
+                return ['success' => false, 'message' => 'Database connection failed'];
+            }
+            
             // Prepare the insert statement
-            $stmt = $this->db->prepare("
+            $stmt = $db->prepare("
                 INSERT INTO delegated_users (
                     username, password_hash, parent_username, display_name, email,
                     can_manage_domains, can_manage_sites, can_manage_databases, 
@@ -93,7 +102,7 @@ class DelegatedUserManager {
                 ':created_by' => $created_by
             ]);
             
-            $delegated_user_id = $this->db->lastInsertId();
+            $delegated_user_id = $db->lastInsertId();
             
             // Log the creation
             $this->logActivity($delegated_user_id, 'user_created', 'delegated_user', $delegated_user_id, 
@@ -112,8 +121,14 @@ class DelegatedUserManager {
      */
     public function authenticateDelegatedUser($username, $password, $ip_address, $user_agent = '') {
         try {
+            // Get database connection
+            $db = $this->getConnection();
+            if (!$db) {
+                return ['success' => false, 'message' => 'Database connection failed'];
+            }
+            
             // Get user from database
-            $stmt = $this->db->prepare("
+            $stmt = $db->prepare("
                 SELECT id, username, password_hash, parent_username, is_active, 
                        failed_login_attempts, locked_until 
                 FROM delegated_users 
@@ -152,7 +167,7 @@ class DelegatedUserManager {
             $session_id = $this->createSession($user['id'], $ip_address, $user_agent);
             
             // Update last login
-            $stmt = $this->db->prepare("UPDATE delegated_users SET last_login = NOW() WHERE id = :id");
+            $stmt = $db->prepare("UPDATE delegated_users SET last_login = NOW() WHERE id = :id");
             $stmt->execute([':id' => $user['id']]);
             
             // Log successful login
@@ -181,7 +196,12 @@ class DelegatedUserManager {
      */
     public function getUserBySession($session_id) {
         try {
-            $stmt = $this->db->prepare("
+            $db = $this->getConnection();
+            if (!$db) {
+                return false;
+            }
+            
+            $stmt = $db->prepare("
                 SELECT du.*, dus.ip_address, dus.last_activity
                 FROM delegated_users du
                 JOIN delegated_user_sessions dus ON du.id = dus.delegated_user_id
@@ -202,7 +222,12 @@ class DelegatedUserManager {
      */
     public function hasPermission($delegated_user_id, $permission, $resource_id = null) {
         try {
-            $stmt = $this->db->prepare("SELECT * FROM delegated_users WHERE id = :id AND is_active = TRUE");
+            $db = $this->getConnection();
+            if (!$db) {
+                return false;
+            }
+            
+            $stmt = $db->prepare("SELECT * FROM delegated_users WHERE id = :id AND is_active = TRUE");
             $stmt->execute([':id' => $delegated_user_id]);
             $user = $stmt->fetch();
             
@@ -247,12 +272,17 @@ class DelegatedUserManager {
      */
     public function getDelegatedUsers($parent_username, $include_inactive = false) {
         try {
+            $db = $this->getConnection();
+            if (!$db) {
+                return [];
+            }
+            
             $where_clause = "parent_username = :parent_username";
             if (!$include_inactive) {
                 $where_clause .= " AND is_active = TRUE";
             }
             
-            $stmt = $this->db->prepare("
+            $stmt = $db->prepare("
                 SELECT id, username, display_name, email, 
                        can_manage_domains, can_manage_sites, can_manage_databases,
                        can_manage_email, can_manage_files, can_manage_backups,
@@ -276,8 +306,13 @@ class DelegatedUserManager {
      */
     public function updateDelegatedUser($user_id, $data, $updated_by) {
         try {
+            $db = $this->getConnection();
+            if (!$db) {
+                return ['success' => false, 'message' => 'Database connection failed'];
+            }
+            
             // Get current user to verify ownership
-            $stmt = $this->db->prepare("SELECT parent_username FROM delegated_users WHERE id = :id");
+            $stmt = $db->prepare("SELECT parent_username FROM delegated_users WHERE id = :id");
             $stmt->execute([':id' => $user_id]);
             $user = $stmt->fetch();
             
@@ -318,7 +353,7 @@ class DelegatedUserManager {
             }
             
             $sql = "UPDATE delegated_users SET " . implode(', ', $update_fields) . " WHERE id = :id";
-            $stmt = $this->db->prepare($sql);
+            $stmt = $db->prepare($sql);
             $stmt->execute($params);
             
             // Log the update
@@ -339,8 +374,13 @@ class DelegatedUserManager {
      */
     public function deleteDelegatedUser($user_id, $deleted_by) {
         try {
+            $db = $this->getConnection();
+            if (!$db) {
+                return ['success' => false, 'message' => 'Database connection failed'];
+            }
+            
             // Get current user to verify ownership
-            $stmt = $this->db->prepare("SELECT username, parent_username FROM delegated_users WHERE id = :id");
+            $stmt = $db->prepare("SELECT username, parent_username FROM delegated_users WHERE id = :id");
             $stmt->execute([':id' => $user_id]);
             $user = $stmt->fetch();
             
@@ -354,7 +394,7 @@ class DelegatedUserManager {
             }
             
             // Delete the user (cascading will handle sessions and activity logs)
-            $stmt = $this->db->prepare("DELETE FROM delegated_users WHERE id = :id");
+            $stmt = $db->prepare("DELETE FROM delegated_users WHERE id = :id");
             $stmt->execute([':id' => $user_id]);
             
             return ['success' => true, 'message' => 'Delegated user deleted successfully'];
@@ -415,7 +455,12 @@ class DelegatedUserManager {
         }
         
         // Check delegated users
-        $stmt = $this->db->prepare("SELECT COUNT(*) FROM delegated_users WHERE username = :username");
+        $db = $this->getConnection();
+        if (!$db) {
+            return true; // Assume exists on DB error for safety
+        }
+        
+        $stmt = $db->prepare("SELECT COUNT(*) FROM delegated_users WHERE username = :username");
         $stmt->execute([':username' => $username]);
         return $stmt->fetchColumn() > 0;
     }
@@ -443,7 +488,12 @@ class DelegatedUserManager {
         $session_id = bin2hex(random_bytes(32));
         $expires_at = date('Y-m-d H:i:s', time() + (24 * 60 * 60)); // 24 hours
         
-        $stmt = $this->db->prepare("
+        $db = $this->getConnection();
+        if (!$db) {
+            return false;
+        }
+        
+        $stmt = $db->prepare("
             INSERT INTO delegated_user_sessions (session_id, delegated_user_id, ip_address, user_agent, expires_at)
             VALUES (:session_id, :delegated_user_id, :ip_address, :user_agent, :expires_at)
         ");
@@ -463,7 +513,13 @@ class DelegatedUserManager {
      * Increment failed login attempts and lock if necessary
      */
     private function incrementFailedLogins($user_id) {
-        $stmt = $this->db->prepare("
+        $db = $this->getConnection();
+        if (!$db) {
+            error_log("Database connection failed in incrementFailedLogins");
+            return;
+        }
+        
+        $stmt = $db->prepare("
             UPDATE delegated_users 
             SET failed_login_attempts = failed_login_attempts + 1,
                 locked_until = CASE 
@@ -479,7 +535,13 @@ class DelegatedUserManager {
      * Reset failed login attempts
      */
     private function resetFailedLogins($user_id) {
-        $stmt = $this->db->prepare("
+        $db = $this->getConnection();
+        if (!$db) {
+            error_log("Database connection failed in resetFailedLogins");
+            return;
+        }
+        
+        $stmt = $db->prepare("
             UPDATE delegated_users 
             SET failed_login_attempts = 0, locked_until = NULL 
             WHERE id = :id
@@ -492,7 +554,13 @@ class DelegatedUserManager {
      */
     private function logActivity($delegated_user_id, $action, $resource_type, $resource_id, $details, $ip_address, $user_agent, $result) {
         try {
-            $stmt = $this->db->prepare("
+            $db = $this->getConnection();
+            if (!$db) {
+                error_log("Database connection failed in logActivity");
+                return;
+            }
+            
+            $stmt = $db->prepare("
                 INSERT INTO delegated_user_activity 
                 (delegated_user_id, action, resource_type, resource_id, details, ip_address, user_agent, result)
                 VALUES (:delegated_user_id, :action, :resource_type, :resource_id, :details, :ip_address, :user_agent, :result)
@@ -518,7 +586,13 @@ class DelegatedUserManager {
      */
     public function cleanupExpiredSessions() {
         try {
-            $stmt = $this->db->prepare("DELETE FROM delegated_user_sessions WHERE expires_at < NOW()");
+            $db = $this->getConnection();
+            if (!$db) {
+                error_log("Database connection failed in cleanupExpiredSessions");
+                return 0;
+            }
+            
+            $stmt = $db->prepare("DELETE FROM delegated_user_sessions WHERE expires_at < NOW()");
             $stmt->execute();
             return $stmt->rowCount();
         } catch (Exception $e) {
@@ -532,7 +606,13 @@ class DelegatedUserManager {
      */
     public function getActivityLog($delegated_user_id, $limit = 100) {
         try {
-            $stmt = $this->db->prepare("
+            $db = $this->getConnection();
+            if (!$db) {
+                error_log("Database connection failed in getActivityLog");
+                return [];
+            }
+            
+            $stmt = $db->prepare("
                 SELECT action, resource_type, resource_id, details, ip_address, result, created_at
                 FROM delegated_user_activity
                 WHERE delegated_user_id = :delegated_user_id
